@@ -256,14 +256,43 @@ class Flask(flask.Flask):
         return self._fsa.create_token(user)
 
     # user
-    def get_user(self):
+    def get_user(self, required=True):
         """Authenticate remote user or raise exception."""
-        return self._fsa.get_user()
+        return self._fsa.get_user(required)
 
     def current_user(self):
         """Get current authenticated user, if any, or None."""
         return self._fsa.current_user()
 
+    # per-method decorator forwarding
+    def get(self, rule, **options):
+        return self._fsa.get(rule, **options)
+
+    def post(self, rule, **options):
+        return self._fsa.post(rule, **options)
+
+    def put(self, rule, **options):
+        return self._fsa.put(rule, **options)
+
+    def delete(self, rule, **options):
+        return self._fsa.delete(rule, **options)
+
+    def patch(self, rule, **options):
+        return self._fsa.patch(rule, **options)
+
+
+# all possible directives
+_DIRECTIVES = {
+    "FSA_401_REDIRECT", "FSA_AUTH", "FSA_CACHE_SIZE", "FSA_CHECK",
+    "FSA_FAKE_LOGIN", "FSA_GET_USER_PASS", "FSA_HTTP_AUTH_OPTS",
+    "FSA_MODE", "FSA_PARAM_PASS", "FSA_PARAM_USER", "FSA_PASSWORD_OPTIONS",
+    "FSA_PASSWORD_SCHEME", "FSA_SKIP_PATH", "FSA_TOKEN_ALGO",
+    "FSA_TOKEN_CARRIER", "FSA_TOKEN_DELAY", "FSA_TOKEN_GRACE",
+    "FSA_TOKEN_LENGTH", "FSA_TOKEN_NAME", "FSA_TOKEN_REALM",
+    "FSA_TOKEN_SECRET", "FSA_TOKEN_SIGN", "FSA_TOKEN_TYPE",
+    "FSA_URL_NAME", "FSA_USER_IN_GROUP", "FSA_LOGGING_LEVEL",
+}
+
 
 # actual extension
 class FlaskSimpleAuth:
@@ -291,6 +320,7 @@ class FlaskSimpleAuth:
     #
     def _auth_set_user(self):
         """Before request hook to perform early authentication."""
+        self._user_set = False
         self._user = None
         self._need_authorization = True
         if self._mode == "lazy":
@@ -300,17 +330,17 @@ class FlaskSimpleAuth:
             if skip(request.path):
                 return
         try:
-            self._user = self.get_user()
+            self.get_user()
         except AuthException as e:
             return self._Resp(e.message, e.status)
-        assert self._user
 
     def _auth_after_cleanup(self, res: Response):
         """After request hook to cleanup authentication and detect missing
         authorization."""
+        self._user_set = False
         self._user = None
         # should it always return 500?
-        # NOTE this may be to late to prevent a commit
+        # NOTE this may be too late to prevent a commit
         if res.status_code < 400 and self._need_authorization:
             method, path = request.method, request.path
             log.warning(f"missing authorization on {method} {path}")
@@ -422,6 +452,12 @@ class FlaskSimpleAuth:
         assert app
         self._app = app
         conf = app.config
+        if "FSA_LOGGING_LEVEL" in conf:
+            log.setLevel(conf["FSA_LOGGING_LEVEL"])
+        # check directives
+        for name in conf:
+            if name[:4] == "FSA_" and name not in _DIRECTIVES:
+                log.warning(f"unexpected directive: {name}")
         #
         # overall auth setup
         #
@@ -451,12 +487,12 @@ class FlaskSimpleAuth:
         #
         self._token = conf.get("FSA_TOKEN_TYPE", "fsa")
         if self._token not in (None, "fsa", "jwt"):
-            raise Exception(f"Unexpected token type (FSA_TOKEN_TYPE): {self._token}")
+            raise Exception(f"Unexpected FSA_TOKEN_TYPE: {self._token}")
         # token carrier
         need_carrier = self._token is not None
         self._carrier = conf.get("FSA_TOKEN_CARRIER", "bearer" if need_carrier else None)
         if self._carrier not in (None, "bearer", "param", "cookie", "header"):
-            raise Exception(f"Unexpected token carrier (FSA_TOKEN_CARRIER): {self._carrier}")
+            raise Exception(f"Unexpected FSA_TOKEN_CARRIER: {self._carrier}")
         # sanity checks
         if need_carrier and not self._carrier:
             raise Exception(f"Token type {self._token} requires a carrier")
@@ -500,7 +536,11 @@ class FlaskSimpleAuth:
             self._sign = self._secret
             self._algo = conf.get("FSA_TOKEN_ALGO", "blake2s")
             self._siglen = conf.get("FSA_TOKEN_LENGTH", 16)
+            if "FSA_TOKEN_SIGN" in conf:
+                log.warning("ignoring FSA_TOKEN_SIGN directive for fsa tokens")
         elif self._token == "jwt":
+            if "FSA_TOKEN_LENGTH" in conf:
+                log.warning("ignoring FSA_TOKEN_LENGTH directive for jwt tokens")
             algo = conf.get("FSA_TOKEN_ALGO", "HS256")
             self._algo = algo
             if algo[0] in ("R", "E", "P"):
@@ -519,7 +559,14 @@ class FlaskSimpleAuth:
         #
         # HTTP parameter names
         #
+        if "fake" not in self._auth and "FSA_FAKE_LOGIN" in conf:
+            log.warning("ignoring directive FSA_FAKE_LOGIN")
         self._login = conf.get("FSA_FAKE_LOGIN", "LOGIN")
+        if "param" not in self._auth and "password" not in self._auth:
+            if "FSA_PARAM_USER" in conf:
+                log.warning("ignoring directive FSA_PARAM_USER")
+            if "FSA_PARAM_PASS" in conf:
+                log.warning("ignoring directive FSA_PARAM_PASS")
         self._userp = conf.get("FSA_PARAM_USER", "USER")
         self._passp = conf.get("FSA_PARAM_PASS", "PASS")
         #
@@ -663,6 +710,8 @@ class FlaskSimpleAuth:
         if not ref:
             log.debug(f"AUTH (password): no such user ({user})")
             raise AuthException(f"no such user: {user}", 401)
+        if not isinstance(ref, (str, bytes)):
+            raise AuthException("get_user_pass must return None or str or bytes", 500)
         if not self.check_password(pwd, ref):
             log.debug(f"AUTH (password): invalid password for {user}")
             raise AuthException(f"invalid password for {user}", 401)
@@ -753,6 +802,7 @@ class FlaskSimpleAuth:
     #
     # FSA_TOKEN_TYPE: 'jwt', 'fsa' or None to disactivate
     # - for 'fsa': format is <realm>:<user>:<validity-limit>:<signature>
+    # FSA_TOKEN_CARRIER: 'param', 'header' or 'bearer'
     # FSA_TOKEN_NAME: name of parameter holding the token, or None for bearer auth
     # FSA_TOKEN_ALGO:
     # - for 'fsa': hashlib algorithm for token authentication ("blake2s")
@@ -922,13 +972,13 @@ class FlaskSimpleAuth:
         "http-token": _get_httpauth,
     }
 
-    def get_user(self) -> str:
+    def get_user(self, required=True) -> Optional[str]:
         """Authenticate user or throw exception."""
         log.debug(f"get_user for {self._auth}")
 
         # _user is reset before/after requests
         # so relying on in-request persistance is safe
-        if self._user:
+        if self._user_set:
             return self._user
 
         assert self._initialized, "FlaskSimpleAuth must be initialized"
@@ -944,16 +994,19 @@ class FlaskSimpleAuth:
                 lae = e
             # FIXME other exceptions?
 
+        # even if not set, we say that the answer is the right one.
+        self._user_set = True
+
         # rethrow last auth exception on failure
-        if not self._user:
+        if required and not self._user:
             raise lae or AuthException("missing authentication", 401)
 
-        log.info(f"get_user({self._auth}): {self._user}")
+        log.debug(f"get_user({self._auth}): {self._user}")
         return self._user
 
     def current_user(self):
         """Return current authenticated user, if any."""
-        return self._user
+        return self.get_user(required=False)
 
     # methods that may be cached
     _CACHABLE = ("_get_jwt_token_auth", "_get_fsa_token_auth", "_get_user_pass", "_user_in_group")
@@ -1027,7 +1080,10 @@ class FlaskSimpleAuth:
                     return fun(*args, **kwargs)
                 # check against all authorized groups/roles
                 for r in groups:
-                    if self._user_in_group(self._user, r):
+                    uig = self._user_in_group(self._user, r)
+                    if not isinstance(uig, bool):
+                        return self._Resp("user_in_group must return a boolean", 500)
+                    if uig:
                         return fun(*args, **kwargs)
                 # else no matching group
                 return self._Resp("", 403)
